@@ -7,4 +7,8 @@ class InvalidOperation(DjangoRESTQLException):
 
 
 class FieldNotFound(DjangoRESTQLException):
-    """Field Not Found Exception."""
\ No newline at end of file
+    """Field Not Found Exception."""
+
+
+class QueryFormatError(DjangoRESTQLException):
+    """Invalid Query Format."""
\ No newline at end of file
