@@ -6,6 +6,7 @@ from rest_framework.serializers import (
     Serializer, ListSerializer,
     ValidationError
 )
+from django.http import QueryDict
 from django.db.models import Prefetch
 from django.utils.functional import cached_property
 from django.db.models.fields.related import ManyToOneRel, ManyToManyRel
@@ -21,6 +22,15 @@ from .fields import (
 
 
 class RequestQueryParserMixin(object):
+    """
+    Mixin for parsing restql query from request.
+
+    NOTE: We are using `request.GET` instead of 
+    `request.query_params` because this might be 
+    called before DRF request is created(i.e from dispatch).
+    This means `request.query_params` might not available
+    when this mixin is used.
+    """
     @staticmethod
     def get_restql_query_param_name():
         DEFAULT_QUERY_PARAM_NAME = 'query'
@@ -34,12 +44,12 @@ class RequestQueryParserMixin(object):
     @classmethod
     def has_restql_query_param(cls, request):
         query_param_name = cls.get_restql_query_param_name()
-        return query_param_name in request.query_params
+        return query_param_name in request.GET
 
     @classmethod
     def get_raw_restql_query(cls, request):
         query_param_name = cls.get_restql_query_param_name()
-        return request.query_params[query_param_name]
+        return request.GET[query_param_name]
 
     @classmethod
     def get_parsed_restql_query_from_req(cls, request):
@@ -55,6 +65,65 @@ class RequestQueryParserMixin(object):
         return parsed_restql_query
 
 
+class QueryArgumentsMixin(RequestQueryParserMixin):
+    """Mixin for converting query arguments into query parameters"""
+    def get_parsed_restql_query(self, request):
+        if self.has_restql_query_param(request):
+            try:
+                return self.get_parsed_restql_query_from_req(request)
+            except (SyntaxError, QueryFormatError):
+                # Let `DynamicFieldsMixin` handle this for a user
+                # to get helpful error message
+                pass
+
+        query = {
+            "include": ["*"],
+            "exclude": [],
+            "arguments": {}
+        }
+        return query
+
+    def build_query_params(self, parsed_query, parent=None):
+        query_params = {}
+        prefix = ''
+        if parent is None:
+            query_params.update(parsed_query['arguments'])
+        else:
+            prefix = parent + '__'
+            for argument, value in parsed_query['arguments'].items():
+                name = prefix + argument
+                query_params.update({
+                    name: value
+                })
+        for field in parsed_query['include']:
+            if isinstance(field, dict):
+                for sub_field, sub_parsed_query in field.items():
+                    nested_query_params = self.build_query_params(
+                        sub_parsed_query,
+                        parent=prefix + sub_field
+                    )
+                    query_params.update(nested_query_params)
+        return query_params
+
+    def get_query_params(self, request):
+        parsed = self.get_parsed_restql_query(request)
+        query_params = self.build_query_params(parsed)
+        return query_params
+
+    def dispatch(self, request, *args, **kwargs):
+        query_params = self.get_query_params(request)
+
+        # We are using `request.GET` instead of `request.query_params`
+        # because at this point DRF request is not yet created so 
+        # `request.query_params` is not yet available
+        params = request.GET.copy()
+        params.update(query_params)
+
+        # Make QueryDict immutable after updating
+        request.GET = QueryDict(params.urlencode(), mutable=False)
+        return super().dispatch(request, *args, **kwargs)
+
+
 class DynamicFieldsMixin(RequestQueryParserMixin):
     def __init__(self, *args, **kwargs):
         # Don't pass 'query', 'fields', 'exclude', 'return_pk' 
@@ -323,6 +392,8 @@ class EagerLoadingMixin(RequestQueryParserMixin):
             try:
                 return self.get_parsed_restql_query_from_req(self.request)
             except (SyntaxError, QueryFormatError):
+                # Let `DynamicFieldsMixin` handle this for a user
+                # to get helpful error message
                 pass
 
         # Else include all fields
